# ATJ Traders - Algo Trading Lib
This is ATJ Trader's Algo Trading Package in Python. It connects to the MetaTrader5 platform and comes with classes
and functions to make Backtesting and Coding of Trading Bots easier. 

## Installation
> pip install atj-algotrading

## Backtesting Tutorial
Please follow this link to access tutorials on Backtesting

## Trading Bot Development Tutorial
Please follow this link to access tutorials on Trading Bot Development